@@ -55,7 +55,7 @@ class Phonon(Property):
                 self.BAND_POINTS = parameter["BAND_POINTS"]
                 parameter["BAND_CONNECTION"] = parameter.get('BAND_CONNECTION', True)
                 self.BAND_CONNECTION = parameter["BAND_CONNECTION"]
-            parameter["cal_type"] = parameter.get("cal_type", "relaxation")
+            parameter["cal_type"] = parameter.get("cal_type", "static")
             default_cal_setting = {
                 "relax_pos": True,
                 "relax_shape": False,
@@ -82,7 +82,7 @@ class Phonon(Property):
     def make_confs(self, path_to_work, path_to_equi, refine=False):
         path_to_work = os.path.abspath(path_to_work)
         if os.path.exists(path_to_work):
-            logging.warning("%s already exists" % path_to_work)
+            logging.debug("%s already exists" % path_to_work)
         else:
             os.makedirs(path_to_work)
         path_to_equi = os.path.abspath(path_to_equi)
@@ -109,7 +109,7 @@ class Phonon(Property):
         cwd = os.getcwd()
 
         if self.reprod:
-            logging.info("phonon reproduce starts")
+            print("phonon reproduce starts")
             if "init_data_path" not in self.parameter:
                 raise RuntimeError("please provide the initial data path to reproduce")
             init_data_path = os.path.abspath(self.parameter["init_data_path"])
@@ -124,7 +124,7 @@ class Phonon(Property):
 
         else:
             if refine:
-                logging.info("phonon refine starts")
+                print("phonon refine starts")
                 task_list = make_refine(
                     self.parameter["init_from_suffix"],
                     self.parameter["output_suffix"],
@@ -178,13 +178,13 @@ class Phonon(Property):
                 if not self.BAND:
                     # use seekpath to get band path
                     if self.seekpath_from_original:
-                        logging.info(msg='Band path (BAND) not indicated, using seekpath from original cell')
+                        print('Band path (BAND) not indicated, using seekpath from original cell')
                         sp = seekpath.get_path_orig_cell(
                             self.get_seekpath_structure(ss),
                             **self.seekpath_param
                         )
                     else:
-                        logging.info(msg='Band path (BAND) not indicated, using seekpath for it')
+                        print('Band path (BAND) not indicated, using seekpath for it')
                         sp = seekpath.get_path(
                             self.get_seekpath_structure(ss),
                             **self.seekpath_param
@@ -193,7 +193,7 @@ class Phonon(Property):
                     self.BAND, self.BAND_LABELS = self.band_list_2_phonopy_band_string(band_list)
                 else:
                     # use user input band path
-                    logging.info(msg=f'Band path (BAND) indicated, using: {self.BAND}')
+                    print(f'Band path (BAND) indicated, using: {self.BAND}')
                     band_list = self.phonopy_band_string_2_band_list(self.BAND, self.BAND_LABELS)
 
                 dumpfn(band_list, os.path.join(path_to_work, "band_path.json"), indent=4)
@@ -485,6 +485,12 @@ class Phonon(Property):
         # return type -> list[list[dict[Any, Any]]]
         return band_list
 
+    @staticmethod
+    def check_same_copy(src, dst):
+        if os.path.samefile(src, dst):
+            return
+        shutil.copyfile(src, dst)
+
     def _compute_lower(self, output_file, all_tasks, all_res):
         cwd = Path.cwd()
         work_path = Path(output_file).parent.absolute()
@@ -497,22 +503,20 @@ class Phonon(Property):
         if not self.reprod:
             os.chdir(work_path)
             if self.inter_param["type"] == 'abacus':
-                shutil.copyfile("task.000000/band.conf", "band.conf")
-                shutil.copyfile("task.000000/STRU.ori", "STRU")
-                shutil.copyfile("task.000000/phonopy_disp.yaml", "phonopy_disp.yaml")
-                os.system('phonopy -f task.0*/OUT.ABACUS/running_scf.log')
+                self.check_same_copy("task.000000/band.conf", "band.conf")
+                self.check_same_copy("task.000000/STRU.ori", "STRU")
+                self.check_same_copy("task.000000/phonopy_disp.yaml", "phonopy_disp.yaml")
                 os.system('phonopy -f task.0*/OUT.ABACUS/running_scf.log')
                 if os.path.exists("FORCE_SETS"):
-                    logging.info('FORCE_SETS is created')
+                    print('FORCE_SETS is created')
                 else:
-                    logging.info('FORCE_SETS can not be created')
+                    logging.warning('FORCE_SETS can not be created')
                 os.system('phonopy band.conf --abacus')
                 os.system('phonopy-bandplot --gnuplot band.yaml > band.dat')
 
             elif self.inter_param["type"] == 'vasp':
-                shutil.copyfile("task.000000/band.conf", "band.conf")
-                if not os.path.samefile("task.000000/POSCAR-unitcell", "POSCAR-unitcell"):
-                    shutil.copyfile("task.000000/POSCAR-unitcell", "POSCAR-unitcell")
+                self.check_same_copy("task.000000/band.conf", "band.conf")
+                self.check_same_copy("task.000000/POSCAR-unitcell", "POSCAR-unitcell")
 
                 if self.approach == "linear":
                     os.chdir(all_tasks[0])
@@ -524,17 +528,17 @@ class Phonon(Property):
                             self.supercell_size[1],
                             self.supercell_size[2]))
                     os.system('phonopy-bandplot --gnuplot band.yaml > band.dat')
-                    logging.info('band.dat is created')
+                    print('band.dat is created')
                     shutil.copyfile("band.dat", work_path/"band.dat")
 
                 elif self.approach == "displacement":
-                    shutil.copyfile("task.000000/band.conf", "band.conf")
-                    shutil.copyfile("task.000000/phonopy_disp.yaml", "phonopy_disp.yaml")
+                    self.check_same_copy("task.000000/band.conf", "band.conf")
+                    self.check_same_copy("task.000000/phonopy_disp.yaml", "phonopy_disp.yaml")
                     os.system('phonopy -f task.0*/vasprun.xml')
                     if os.path.exists("FORCE_SETS"):
-                        logging.info('FORCE_SETS is created')
+                        print('FORCE_SETS is created')
                     else:
-                        logging.info('FORCE_SETS can not be created')
+                        logging.warning('FORCE_SETS can not be created')
                     os.system('phonopy --dim="%s %s %s" -c POSCAR-unitcell band.conf' % (
                         self.supercell_size[0],
                         self.supercell_size[1],
